@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11599 2019-06-01 18:56:30Z Lavender $
+# $Id: __init__.py 12224 2020-05-15 09:54:33Z Andy $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,12 +11,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2019-06-02 02:56:30 +0800 (週日, 02 六月 2019) $
-# $Revision: 11599 $
+# $Author: Andy $
+# $Date: 2020-05-15 17:54:33 +0800 (週五, 15 五月 2020) $
+# $Revision: 12224 $
 
 from django.conf import settings as _settings
 from django.utils.translation import ugettext_lazy as _
+from django.conf.urls import url, include
+
+from Iuppiter.DjangoUtil import DJANGO_VERSION
 
 default_app_config = 'Zephyrus.comment.apps.CommentConfig'
 
@@ -44,3 +47,23 @@ class settings(object):
         for ele in _settings.ZEPHYRUS_RECENTRESPONSE_TEMPLATES:
             if not ele[0] == ZEPHYRUS_RECENTRESPONSE_DEFAULT_TEMPLATE:
                 ZEPHYRUS_RECENTRESPONSE_TEMPLATES.append(ele)
+
+def patterns(prefix, *args): 
+    if DJANGO_VERSION >= 11100: # django >= 1.11
+        return list(args)
+    else:
+        from django.conf.urls import patterns as _patterns
+        
+        return _patterns(prefix, *args)
+
+def attachURLs(settings, urlpatterns):
+    """
+    Attach patched (for example, debug and admin...etc.) urlpatterns.
+    It must be called in urls.py by passing urlpatterns.
+
+    @param settings Django project's settings module.
+    @param urlpatterns urlpatterns in urls.py.
+    """
+    urlpatterns += patterns('',
+        url(r'^', include('Zephyrus.comment.urls')),
+    )
\ No newline at end of file
