@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12224 2020-05-15 09:54:33Z Andy $
+# $Id: __init__.py 12251 2020-05-20 19:31:27Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Andy $
-# $Date: 2020-05-15 17:54:33 +0800 (週五, 15 五月 2020) $
-# $Revision: 12224 $
+# $Author: Lavender $
+# $Date: 2020-05-21 03:31:27 +0800 (週四, 21 五月 2020) $
+# $Revision: 12251 $
 
 import json
 import requests
@@ -35,7 +35,8 @@ else:
 
 class Settings(object):
     # Facebook Nuwa Blog APP
-    ZEPHYRUS_FACEBOOK_DEFAULT_GET_ACCESS_TOKEN_URL = "https://www.nuwainfo.com"
+    ZEPHYRUS_FACEBOOK_DEFAULT_GET_ACCESS_TOKEN_URL = "https://lavender.nuwainfo.com:12345"
+    ZEPHYRUS_FACEBOOK_DEFAULT_SECRET_KEY = "k*ohwp_!xr!rz*+6b2fpff%&5tw!nyh__^#y0%w#53k11#nh9p"
     ZEPHYRUS_FACEBOOK_DEFAULT_PASSWORD = "@%)@5529"
     ZEPHYRUS_FACEBOOK_DEFAULT_APP_ID = "1435073943305111"
     ZEPHYRUS_FACEBOOK_DEFAULT_APP_SECRET = "1f0ba7a626695ee0c5419627c2d0a8b9"
